#[non_exhaustive]pub enum PathValue {
Value(Box<Value>),
ValueMatcher(Box<ValueMatcher>),
}Expand description
One of the fields in the following block will be set and intend to describe a value for ‘path’ field.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Value(Box<Value>)
Value for the path field. Will be set for actions:‘add’/‘replace’.
Maybe set for action: ‘test’. Either this or value_matcher will be set
for ‘test’ operation. An exact match must be performed.
ValueMatcher(Box<ValueMatcher>)
Can be set for action ‘test’ for advanced matching for the value of
‘path’ field. Either this or value will be set for ‘test’ operation.