#[non_exhaustive]pub struct InsightTypeConfig {
pub name: String,
pub insight_type_generation_config: Option<InsightTypeGenerationConfig>,
pub etag: String,
pub update_time: Option<Timestamp>,
pub revision_id: String,
pub annotations: HashMap<String, String>,
pub display_name: String,
/* private fields */
}Expand description
Configuration for an InsightType.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringName of insight type config. Eg, projects/[PROJECT_NUMBER]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID]/config
insight_type_generation_config: Option<InsightTypeGenerationConfig>InsightTypeGenerationConfig which configures the generation of insights for this insight type.
etag: StringFingerprint of the InsightTypeConfig. Provides optimistic locking when updating.
update_time: Option<Timestamp>Last time when the config was updated.
revision_id: StringOutput only. Immutable. The revision ID of the config. A new revision is committed whenever the config is changed in any way. The format is an 8-character hexadecimal string.
annotations: HashMap<String, String>Allows clients to store small amounts of arbitrary data. Annotations must follow the Kubernetes syntax. The total size of all keys and values combined is limited to 256k. Key can have 2 segments: prefix (optional) and name (required), separated by a slash (/). Prefix must be a DNS subdomain. Name must be 63 characters or less, begin and end with alphanumerics, with dashes (-), underscores (_), dots (.), and alphanumerics between.
display_name: StringA user-settable field to provide a human-readable name to be used in user interfaces.
Implementations
Sourceimpl InsightTypeConfig
impl InsightTypeConfig
Sourcepub fn set_insight_type_generation_config<T>(self, v: T) -> Selfwhere
T: Into<InsightTypeGenerationConfig>,
pub fn set_insight_type_generation_config<T>(self, v: T) -> Selfwhere
T: Into<InsightTypeGenerationConfig>,
Sets the value of insight_type_generation_config.
Example
use google_cloud_recommender_v1::model::InsightTypeGenerationConfig;
let x = InsightTypeConfig::new().set_insight_type_generation_config(InsightTypeGenerationConfig::default()/* use setters */);Sourcepub fn set_or_clear_insight_type_generation_config<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<InsightTypeGenerationConfig>,
pub fn set_or_clear_insight_type_generation_config<T>(
self,
v: Option<T>,
) -> Selfwhere
T: Into<InsightTypeGenerationConfig>,
Sets or clears the value of insight_type_generation_config.
Example
use google_cloud_recommender_v1::model::InsightTypeGenerationConfig;
let x = InsightTypeConfig::new().set_or_clear_insight_type_generation_config(Some(InsightTypeGenerationConfig::default()/* use setters */));
let x = InsightTypeConfig::new().set_or_clear_insight_type_generation_config(None::<InsightTypeGenerationConfig>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = InsightTypeConfig::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = InsightTypeConfig::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = InsightTypeConfig::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_revision_id<T: Into<String>>(self, v: T) -> Self
pub fn set_revision_id<T: Into<String>>(self, v: T) -> Self
Sets the value of revision_id.
Example
let x = InsightTypeConfig::new().set_revision_id("example");Sourcepub fn set_annotations<T, K, V>(self, v: T) -> Self
pub fn set_annotations<T, K, V>(self, v: T) -> Self
Sets the value of annotations.
Example
let x = InsightTypeConfig::new().set_annotations([
("key0", "abc"),
("key1", "xyz"),
]);Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
let x = InsightTypeConfig::new().set_display_name("example");Trait Implementations
Sourceimpl Clone for InsightTypeConfig
impl Clone for InsightTypeConfig
Sourcefn clone(&self) -> InsightTypeConfig
fn clone(&self) -> InsightTypeConfig
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more