#[non_exhaustive]pub struct ListInsightsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request for the ListInsights method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The container resource on which to execute the request. Acceptable formats:
-
projects/[PROJECT_NUMBER]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID] -
projects/[PROJECT_ID]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID] -
billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID] -
folders/[FOLDER_ID]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID] -
organizations/[ORGANIZATION_ID]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID]
LOCATION here refers to GCP Locations: https://cloud.google.com/about/locations/ INSIGHT_TYPE_ID refers to supported insight types: https://cloud.google.com/recommender/docs/insights/insight-types.
page_size: i32Optional. The maximum number of results to return from this request. Non-positive values are ignored. If not specified, the server will determine the number of results to return.
page_token: StringOptional. If present, retrieves the next batch of results from the
preceding call to this method. page_token must be the value of
next_page_token from the previous response. The values of other method
parameters must be identical to those in the previous call.
filter: StringOptional. Filter expression to restrict the insights returned. Supported filter fields:
-
stateInfo.state -
insightSubtype -
severity -
targetResources
Examples:
-
stateInfo.state = ACTIVE OR stateInfo.state = DISMISSED -
insightSubtype = PERMISSIONS_USAGE -
severity = CRITICAL OR severity = HIGH -
targetResources : //compute.googleapis.com/projects/1234/zones/us-central1-a/instances/instance-1 -
stateInfo.state = ACTIVE AND (severity = CRITICAL OR severity = HIGH)
The max allowed filter length is 500 characters.
(These expressions are based on the filter language described at https://google.aip.dev/160)
Implementations
Sourceimpl ListInsightsRequest
impl ListInsightsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListInsightsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListInsightsRequest
impl Clone for ListInsightsRequest
Sourcefn clone(&self) -> ListInsightsRequest
fn clone(&self) -> ListInsightsRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more