#[non_exhaustive]pub struct ListRecommendationsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request for the ListRecommendations method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The container resource on which to execute the request. Acceptable formats:
-
projects/[PROJECT_NUMBER]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID] -
projects/[PROJECT_ID]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID] -
billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID] -
folders/[FOLDER_ID]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID] -
organizations/[ORGANIZATION_ID]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID]
LOCATION here refers to GCP Locations: https://cloud.google.com/about/locations/ RECOMMENDER_ID refers to supported recommenders: https://cloud.google.com/recommender/docs/recommenders.
page_size: i32Optional. The maximum number of results to return from this request. Non-positive values are ignored. If not specified, the server will determine the number of results to return.
page_token: StringOptional. If present, retrieves the next batch of results from the
preceding call to this method. page_token must be the value of
next_page_token from the previous response. The values of other method
parameters must be identical to those in the previous call.
filter: StringFilter expression to restrict the recommendations returned. Supported filter fields:
-
state_info.state -
recommenderSubtype -
priority -
targetResources
Examples:
-
stateInfo.state = ACTIVE OR stateInfo.state = DISMISSED -
recommenderSubtype = REMOVE_ROLE OR recommenderSubtype = REPLACE_ROLE -
priority = P1 OR priority = P2 -
targetResources : //compute.googleapis.com/projects/1234/zones/us-central1-a/instances/instance-1 -
stateInfo.state = ACTIVE AND (priority = P1 OR priority = P2)
The max allowed filter length is 500 characters.
(These expressions are based on the filter language described at https://google.aip.dev/160)
Implementations
Sourceimpl ListRecommendationsRequest
impl ListRecommendationsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListRecommendationsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListRecommendationsRequest
impl Clone for ListRecommendationsRequest
Sourcefn clone(&self) -> ListRecommendationsRequest
fn clone(&self) -> ListRecommendationsRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more