OperationGroup

Struct OperationGroup 

#[non_exhaustive]
pub struct OperationGroup { pub operations: Vec<Operation>, /* private fields */ }
Group of operations that need to be performed atomically.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
operations: Vec<Operation>

List of operations across one or more resources that belong to this group. Loosely based on RFC6902 and should be performed in the order they appear.

Implementations

Source

impl OperationGroup

pub fn new() -> Self

Creates a new default instance.

pub fn set_operations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Operation>,

Sets the value of operations.

Example
use google_cloud_recommender_v1::model::Operation;
let x = OperationGroup::new()
    .set_operations([
        Operation::default()/* use setters */,
        Operation::default()/* use (different) setters */,
    ]);