#[non_exhaustive]pub struct RecommendationContent {
pub operation_groups: Vec<OperationGroup>,
pub overview: Option<Struct>,
/* private fields */
}Expand description
Contains what resources are changing and how they are changing.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.operation_groups: Vec<OperationGroup>Operations to one or more Google Cloud resources grouped in such a way that, all operations within one group are expected to be performed atomically and in an order.
overview: Option<Struct>Condensed overview information about the recommendation.
Implementations
Sourceimpl RecommendationContent
impl RecommendationContent
Sourcepub fn set_operation_groups<T, V>(self, v: T) -> Self
pub fn set_operation_groups<T, V>(self, v: T) -> Self
Sets the value of operation_groups.
Example
ⓘ
use google_cloud_recommender_v1::model::OperationGroup;
let x = RecommendationContent::new()
.set_operation_groups([
OperationGroup::default()/* use setters */,
OperationGroup::default()/* use (different) setters */,
]);Sourcepub fn set_overview<T>(self, v: T) -> Self
pub fn set_overview<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_overview<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_overview<T>(self, v: Option<T>) -> Self