#[non_exhaustive]pub struct RecommenderGenerationConfig {
pub params: Option<Struct>,
/* private fields */
}Expand description
A Configuration to customize the generation of recommendations. Eg, customizing the lookback period considered when generating a recommendation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.params: Option<Struct>Parameters for this RecommenderGenerationConfig. These configs can be used by or are applied to all subtypes.
Implementations
Sourceimpl RecommenderGenerationConfig
impl RecommenderGenerationConfig
pub fn new() -> Self
Sourcepub fn set_params<T>(self, v: T) -> Self
pub fn set_params<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_params<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_params<T>(self, v: Option<T>) -> Self