#[non_exhaustive]pub struct SecurityProjection {
pub details: Option<Struct>,
/* private fields */
}Expand description
Contains various ways of describing the impact on Security.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.details: Option<Struct>Additional security impact details that is provided by the recommender.
Implementations
Sourceimpl SecurityProjection
impl SecurityProjection
Sourcepub fn set_details<T>(self, v: T) -> Self
pub fn set_details<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_details<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_details<T>(self, v: Option<T>) -> Self