#[non_exhaustive]pub struct UpdateInsightTypeConfigRequest {
pub insight_type_config: Option<InsightTypeConfig>,
pub update_mask: Option<FieldMask>,
pub validate_only: bool,
/* private fields */
}Expand description
Request for the UpdateInsightTypeConfig method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.insight_type_config: Option<InsightTypeConfig>Required. The InsightTypeConfig to update.
update_mask: Option<FieldMask>The list of fields to be updated.
validate_only: boolIf true, validate the request and preview the change, but do not actually update it.
Implementations
Sourceimpl UpdateInsightTypeConfigRequest
impl UpdateInsightTypeConfigRequest
Sourcepub fn set_insight_type_config<T>(self, v: T) -> Selfwhere
T: Into<InsightTypeConfig>,
pub fn set_insight_type_config<T>(self, v: T) -> Selfwhere
T: Into<InsightTypeConfig>,
Sets the value of insight_type_config.
Example
ⓘ
use google_cloud_recommender_v1::model::InsightTypeConfig;
let x = UpdateInsightTypeConfigRequest::new().set_insight_type_config(InsightTypeConfig::default()/* use setters */);Sourcepub fn set_or_clear_insight_type_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InsightTypeConfig>,
pub fn set_or_clear_insight_type_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<InsightTypeConfig>,
Sets or clears the value of insight_type_config.
Example
ⓘ
use google_cloud_recommender_v1::model::InsightTypeConfig;
let x = UpdateInsightTypeConfigRequest::new().set_or_clear_insight_type_config(Some(InsightTypeConfig::default()/* use setters */));
let x = UpdateInsightTypeConfigRequest::new().set_or_clear_insight_type_config(None::<InsightTypeConfig>);Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateInsightTypeConfigRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateInsightTypeConfigRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateInsightTypeConfigRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
pub fn set_validate_only<T: Into<bool>>(self, v: T) -> Self
Sets the value of validate_only.
Example
ⓘ
let x = UpdateInsightTypeConfigRequest::new().set_validate_only(true);Trait Implementations
Sourceimpl Clone for UpdateInsightTypeConfigRequest
impl Clone for UpdateInsightTypeConfigRequest
Sourcefn clone(&self) -> UpdateInsightTypeConfigRequest
fn clone(&self) -> UpdateInsightTypeConfigRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for UpdateInsightTypeConfigRequest
impl Default for UpdateInsightTypeConfigRequest
Sourcefn default() -> UpdateInsightTypeConfigRequest
fn default() -> UpdateInsightTypeConfigRequest
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for UpdateInsightTypeConfigRequest
impl PartialEq for UpdateInsightTypeConfigRequest
Sourcefn eq(&self, other: &UpdateInsightTypeConfigRequest) -> bool
fn eq(&self, other: &UpdateInsightTypeConfigRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UpdateInsightTypeConfigRequest