#[non_exhaustive]pub struct OperationGroup {
pub operations: Vec<Operation>,
/* private fields */
}Expand description
Group of operations that need to be performed atomically.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.operations: Vec<Operation>List of operations across one or more resources that belong to this group. Loosely based on RFC6902 and should be performed in the order they appear.
Implementations
Sourceimpl OperationGroup
impl OperationGroup
Sourcepub fn set_operations<T, V>(self, v: T) -> Self
pub fn set_operations<T, V>(self, v: T) -> Self
Sets the value of operations.
Example
ⓘ
use google_cloud_recommender_v1::model::Operation;
let x = OperationGroup::new()
.set_operations([
Operation::default()/* use setters */,
Operation::default()/* use (different) setters */,
]);Trait Implementations
Sourceimpl Clone for OperationGroup
impl Clone for OperationGroup
Sourcefn clone(&self) -> OperationGroup
fn clone(&self) -> OperationGroup
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperationGroup
impl Debug for OperationGroup
Sourceimpl Default for OperationGroup
impl Default for OperationGroup
Sourcefn default() -> OperationGroup
fn default() -> OperationGroup
Returns the “default value” for a type. Read more
Sourceimpl Message for OperationGroup
impl Message for OperationGroup
Sourceimpl PartialEq for OperationGroup
impl PartialEq for OperationGroup
impl StructuralPartialEq for OperationGroup